4.7.1 (2024-04-19)
==================

👷 Bug fixes
------------

- serverctl: use the dump-s3 options for the db-restore command

4.7.0 (2024-04-03)
==================

🎉 New features
---------------

- entity: harden `Entity.cw_instantiate` in debug mode
